@@ -1,9 +1,13 @@
+""" AverageSpeed class """
+
 from dataclasses import dataclass
 
+
 @dataclass
-class AverageSpeed:
+class AverageSpeed():
     """
     Representation of a Drivers Average Speed
+
     Average Speeds may contain:
         units: String
         speed: Float
@@ -12,10 +16,7 @@ class AverageSpeed:
     def __init__(self, units: str, speed: float) -> None:
         self.units = units
         self.speed = speed
-        pass
 
-    def __str__(self):
-        return f"AverageSpeed(units={self.units}, speed={self.speed})"
-
-    def __repr__(self):
-        return f"AverageSpeed(units={self.units}, speed={self.speed})"
\ No newline at end of file
+    def __repr__(self) -> str:
+        members = ', '.join(f"{key}={value}" for key, value in self.__dict__.items())
+        return f"{type(self).__name__}({members})"
