@@ -1,11 +1,15 @@
+""" Lap class """
+
 from dataclasses import dataclass
 
 from ergast_py.models.timing import Timing
 
+
 @dataclass
-class Lap:
+class Lap():
     """
     Representation of a single Lap from a Formula One race
+
     Laps may contain:
         number: Integer
         timings: Timing[]
@@ -14,10 +18,7 @@ class Lap:
     def __init__(self, number: int, timings: list[Timing]) -> None:
         self.number = number
         self.timings = timings
-        pass
 
-    def __str__(self):
-        return f"Lap(number={self.number}, timings={self.timings})"
-
-    def __repr__(self):
-        return f"Lap(number={self.number}, timings={self.timings})"
\ No newline at end of file
+    def __repr__(self) -> str:
+        members = ', '.join(f"{key}={value}" for key, value in self.__dict__.items())
+        return f"{type(self).__name__}({members})"
