@@ -1,9 +1,13 @@
+""" Location class """
+
 from dataclasses import dataclass
 
+
 @dataclass
-class Location:
+class Location():
     """
     Representation of a Location for a Formula One Circuit
+
     Locations may contain:
         lat: Float
         long: Float
@@ -16,10 +20,7 @@ class Location:
         self.longitude = longitude
         self.locality = locality
         self.country = country
-        pass
 
-    def __str__(self):
-        return f"Location(latitude={self.latitude},longitude={self.longitude}, locality={self.locality}, country={self.country})"
-
-    def __repr__(self):
-        return f"Location(latitude={self.latitude},longitude={self.longitude}, locality={self.locality}, country={self.country})"
\ No newline at end of file
+    def __repr__(self) -> str:
+        members = ', '.join(f"{key}={value}" for key, value in self.__dict__.items())
+        return f"{type(self).__name__}({members})"
