@@ -1,9 +1,13 @@
+""" Season class """
+
 from dataclasses import dataclass
 
+
 @dataclass
-class Season:
+class Season():
     """
     Representation of a single Season in Formula One
+
     Seasons may contain:
         season: Integer
         url: String
@@ -12,10 +16,7 @@ class Season:
     def __init__(self, season: int, url: str) -> None:
         self.season = season
         self.url = url
-        pass
 
-    def __str__(self):
-        return f"Season(season={self.season}, url={self.url})"
-
-    def __repr__(self):
-        return f"Season(season={self.season}, url={self.url})"
\ No newline at end of file
+    def __repr__(self) -> str:
+        members = ', '.join(f"{key}={value}" for key, value in self.__dict__.items())
+        return f"{type(self).__name__}({members})"
